@@ -1002,8 +1002,8 @@ draw_key_label (MatekbdKeyboardDrawingRenderContext * context,
 	}
 }
 
-/**
-   The x offset is calculated for complex shapes. It is the rightmost of the vertical lines in the outline
+/*
+ * The x offset is calculated for complex shapes. It is the rightmost of the vertical lines in the outline
  */
 static gint
 calc_origin_offset_x (XkbOutlineRec * outline)
@@ -1584,6 +1584,8 @@ unpress_keys (MatekbdKeyboardDrawing * drawing)
 {
 	gint i;
 
+	drawing->timeout = 0;
+
 	if (!drawing->xkb)
 		return FALSE;
 
@@ -1610,7 +1612,7 @@ focus_event (GtkWidget * widget,
 	if (event->in && drawing->timeout > 0) {
 		g_source_remove (drawing->timeout);
 		drawing->timeout = 0;
-	} else
+	} else if (drawing->timeout == 0)
 		drawing->timeout =
 		    g_timeout_add (120, (GSourceFunc) unpress_keys,
 				   drawing);
@@ -2225,7 +2227,7 @@ matekbd_keyboard_drawing_set_mods (MatekbdKeyboardDrawing * drawing, guint mods)
  * from e.g. a GtkWidget or a GtkPrintContext.  @cr and @layout may be modified
  * by the function but will not be unreffed.
  *
- * @returns:   %TRUE on success, %FALSE on failure
+ * Returns: %TRUE on success, %FALSE on failure
  */
 gboolean
 matekbd_keyboard_drawing_render (MatekbdKeyboardDrawing * kbdrawing,
